Stan Math Library: stan/math/prim/scal/fun/bessel_first_kind.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

bessel_first_kind.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_BESSEL_FIRST_KIND_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_BESSEL_FIRST_KIND_HPP
3
4 #include <boost/math/special_functions/bessel.hpp>
5 #include <stan/math/prim/scal/err/check_not_nan.hpp>
6
7 namespace stan {
8 namespace math {
9
38 template<typename T2>
39 inline T2
40 bessel_first_kind(const int v, const T2 z) {
41 using stan::math::check_not_nan;
42
43 check_not_nan("bessel_first_kind", "z", z);
44 return boost::math::cyl_bessel_j(v, z);
45 }
46
47 }
48 }
49
50 #endif
check_not_nan.hpp
stan::math::check_not_nan
bool check_not_nan(const char *function, const char *name, const T_y &y)
Return true if y is not NaN.
Definition: check_not_nan.hpp:63
stan::math::bessel_first_kind
fvar< T > bessel_first_kind(int v, const fvar< T > &z)
Definition: bessel_first_kind.hpp:15
stan
Definition: log_sum_exp.hpp:8

[ Stan Home Page ] © 2011–2016, Stan Development Team.